#
# spec file for package di
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           di
Version:        4.51
Release:        150400.3.pm.83
Summary:        Disk Information Utility
License:        Zlib
Group:          Productivity/File utilities
URL:            https://diskinfo-di.sourceforge.io/
Source:         https://sourceforge.net/projects/diskinfo-di/files/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig

%description
di is a disk information utility that displays everything that df does and
more. It features the ability to display your disk usage in whatever format you
prefer. It also checks the user and group quotas, so that the user sees the
space available for their use, not the system wide disk space. It is designed
to be highly portable across many platforms and is great for heterogenous
networks.

%prep
%autosetup

%build
make %{?_smp_mflags} \
    prefix="%{_prefix}" \
    LOCALEDIR="%{_datadir}/locale" \
    CC="gcc" \
    CFLAGS="%{optflags}"

%install
# actually needed on some non-openSUSE dists as the install
# target doesn't use "mkdir -p" but just "mkdir"
install -d %{buildroot}

make \
    prefix="%{_prefix}" \
    LOCALEDIR="%{_datadir}/locale" \
    CC="gcc" \
    CFLAGS="%{optflags}" \
    INSTALL_DIR="%{buildroot}%{_prefix}" \
    INSTALL_BIN_DIR="%{buildroot}%{_bindir}" \
    INSTALL_LOCALEDIR="%{buildroot}%{_datadir}/locale" \
    DI_MANINSTDIR="%{buildroot}%{_mandir}" \
    install

%find_lang %{name}

%files -f %{name}.lang
%license LICENSE
%doc MANIFEST README.txt
%{_bindir}/di
%{_bindir}/mi
%{_mandir}/man1/di.1%{ext_man}

%changelog
* Tue Nov  9 2021 Andreas Stieger <andreas.stieger@gmx.de>
- di 4.51:
  * Handle EPERM errors
- di 4.50:
  * JSON: Exclude extraneous format characters from the json output
  * JSON: Fix quoting around human-readable values
  * Totals: Support APFS filesystem
  * Linux: Put filesytems using 'tmpfs' or 'cgroup' as the
    device name on the ignore list
- di 4.49:
  * Added the -j (--json-output) option to output json data
- di 4.48:
  * disable spurious compiler warnings
  * Various build fixes
* Tue Jun  2 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.47.3
  * Fixed missing link flags for clang.
  version 4.47.2:
  * Minor makefile cleanup.
  version 4.47.1:
  * Update mkconfig to version 2.1.1 (fixes build on 32-bit).
  * Add configs/config.ms.cl (visual studio definitions).
* Mon Aug 13 2018 mvetter@suse.com
- Update to 4.47:
  * Fixed bugs located by scan.coverity.com.
    This should fix a numeric sort bug.
  * Update mkconfig to version 2.0.0 and make changes to
    support it.
  * Get perl extension build working again.
* Thu Jun 14 2018 mvetter@suse.com
- Update to 4.46:
  * Tcl: Fix bad allocation.
  * Tcl: Raise errors rather than exiting.
  * Exit program when incorrect options are specified.
  * Update mkconfig to version 1.31.
  * Add missing mkconfig/runtests.sh.
  * Update mkconfig to version 1.30 to fix modern libintl.h/printf tests.
* Mon Mar 19 2018 aloisio@gmx.com
- Update to version 4.44
  * Fixed check of exabyte sized filesystems.  The signed check
    now only checks for -1 and -2; there could still be situations
    where the overflow exactly matches these values.
  * Added faster method for windows check for missing removable
    filesystems.
  version 4.43
  * Cleaned up some compiler warnings.
  * Fixed memory allocation problem.
  * Tcl interface fixes
  version 4.42
  * Fixed a parsing bug in the Tcl interface.
  * Added a Perl interface.
  version 4.41
  * Fixed bug specifying more than one filesystem on the command
    line.
  * Added sort by free space, total space.
  * Updated manual page: missing, new sort options.
  version 4.40
  * Updated the Tcl interface to return the 'display' key as a list.
  version 4.39
  * Added a Tcl interface.
  * Fixed CSV header to honor -n flag.
  * Added -C, --csv-tabs to output CSV with tabs.
  * Update mkconfig to version 1.27
  version 4.38
  * Update mkconfig to version 1.26
  version 4.37
  * Fixed a problem when processing the DI_ARGS environment variable.
  * Hardened compiler options: reference:
    http://wiki.debian.org/Hardening
  * Code cleanup to fix compiler warnings.
  version 4.36
  * Updated test for NFS remote filesystems.
  version 4.35
  * Fixed a bug when -I/-x were specified in addition to a filespec.
  * Updated build system to mkconfig-1.24
  version 4.34
  * When a filename is specified on the command line, attempt to
    choose the best filesystem to display when there are multiple
    choices.
  * Error check realpath() return value.
  * Only canonicalize device names if it has a trailing uuid.
  * Add -R (--dont-resolve-symlink) option to turn off
    canonicalization.
  * Clean up code to fix clang warnings.
  version 4.33
  * Recoded quota handling as information was improperly
    losing precision.
  * Added support for hammer-pfs (pooled filesystems).
  * Exclude rootfs, devfs, procfs, kernfs, ptyfs and devtmpfs by
    default.
  * Minor updates to main makefile.
  * Minor directory rearrangement for os-specific config files.
  * Fixed possible case of systems with a memcpy macro and
    no library function.
  * Make sure D tests are not run.
  * Updated build system to mkconfig-1.22.
  version 4.32
  * Exclude rootfs by default.
  * Canonicalize the special device name.
  * Updated build system to mkconfig-1.21.
  version 4.31
  * Filesystems that would return a 'Permission Denied'
    are not displayed at all, even with -a.
  * Fixed totals with pooled filesystems (when main pool not
    mounted).
  * Fixed a very rare divide by 0 condition.
  * Code cleanup.
  * Updated build system to mkconfig-1.19.
- Spec cleanup
* Mon Nov 21 2011 pascal.bleser@opensuse.org
- update to 4.31:
  * filesystems that would return a 'Permission Denied' no longer generate an
    error message and are no longer displayed, even with the -a option
  * bugfixes include fixing the totals for pooled (zfs) filesystems when the
    main pool is not mounted and a rare divide by 0 condition
* Fri Oct 14 2011 pascal.bleser@opensuse.org
- update to 4.30:
  * support for long commandline options was added
* Sun Oct  2 2011 pascal.bleser@opensuse.org
- update to 4.29
- rewrote spec file to comply with nowadays' style guide and
  good practices
- moved to utilities on build.o.o
* Sun Jan  2 2011 detlef@links2linux.de
- new upstream version <4.27>
  * Rearranged directory structure.
  * Added support for long double to hold zettas and yottas.
  * Added support for the windows digital mars c compiler.
  * Added a fix for windows removable drives.
  * Rewrote snprintf macros as they didn't work on MacOSX.
  * Fixed quotactl argument for systems w/o QCMD macro.
  * Check for type of structure members and call the correct xdr function.
  * Many minor fixes for compiler warnings.
  * Fixed Makefiles to redirect 'cd' output (CDPATH).
  * Updated build system to mkconfig 1.11.
* Mon Jul 26 2010 detlef@links2linux.de
- new upstream version <4.26>
  * Fix FreeBSD 5 panic when trying to get quotas on devfs.
  * Updated build system to mkconfig-1.10.
* Mon Jul  5 2010 detlef@links2linux.de
- new upstream version <4.25>
  * Added support for quotas.
  * Fix for Tru64 advfs pools.
  * Fixed loopback filesystem (lofs/none) exclusion; enabled for
    all systems.
  * Added an optional DI_LOCALE_DIR environment variable to
    point to the locale directory where di's messages are installed.
  * Changed the sort to use strcoll() rather than strcmp().
  * Updated build system to mkconfig-1.6.
  * Removed turnoffwinapi.sh, hasnls.sh & turnoffnls.sh and updated
    to use new build system tools.
  * Added dioptions.dat to control options.
  * More fixes for totals in a pooled/non-pooled mix when pooled
    filesystems are not displayed.
* Sat May 15 2010 detlef@links2linux.de
- initial build for PackMan <4.24>
